@@ -10,7 +10,7 @@ import publication
 from jsii.python import classproperty
 
 import aws_cdk.aws_ec2
-import aws_cdk.cdk
+import aws_cdk.core
 __all__ = []
 
 publication.publish()
